import type { IAddMZCfdpComment } from '@/types/prescript/TTemplate';
export const useFormValid = (data?: IAddMZCfdpComment) => {
  const formData = ref();
  const errorMessage = ref<string>('');
  formData.value = data;

  /**
   * @description 验证年龄范围
   * @param {string} patientAgeStart 开始年龄
   * @param {string} patientAgeEnd 结束年龄
   * @param {string} errMessage 自定义错误信息
   * @returns {string} 错误信息
   */
  const validAge = (
    patientAgeStart: string,
    patientAgeEnd: string,
    errMessage: string = '开始年龄不能大于结束年龄'
  ) => {
    if (!patientAgeStart || !patientAgeEnd) {
      return (errorMessage.value = '');
    }
    if (patientAgeEnd < patientAgeStart) {
      return (errorMessage.value = errMessage);
    }
    errorMessage.value = ''; // 清空错误信息
    return errorMessage.value;
  };

  /**
   * @description 校验数字或非负数
   * @param {string} value 输入的值
   * @param {boolean} isNonNegative 是否为非负数（默认校验数字）
   * @param {string} errMessage 自定义错误信息
   * @returns {string} 错误信息
   */
  const validNumber = (
    value: string,
    isNonNegative: boolean = false,
    errMessage: string = '输入值无效'
  ) => {
    if (!value) {
      return '';
    }

    const numberValue = Number(value);

    // 校验是否为数字
    if (isNaN(numberValue)) {
      return errMessage; // 如果不是数字，返回错误信息
    }

    // 如果是非负数校验
    if (isNonNegative && numberValue < 0) {
      return '输入值必须为非负数';
    }

    return ''; // 校验通过，返回空错误信息
  };

  // 校验年龄
  const handleValidAge = (patientAgeStart: string, patientAgeEnd: string) => {
    if (!patientAgeStart && !patientAgeEnd) {
      return '';
    }
    // 校验是否为数字且非负数
    const isValidNumber = (value: string) => {
      const numberValue = Number(value);
      return !isNaN(numberValue) && numberValue >= 0;
    };

    // 校验开始年龄和结束年龄
    if (!isValidNumber(patientAgeStart) || !isValidNumber(patientAgeEnd)) {
      return '输入值必须是有效的非负数字';
    }

    if (Number(patientAgeEnd) < Number(patientAgeStart)) {
      return '结束值不能小于起始值';
    }

    return ''; // 校验通过，返回空字符串表示没有错误
  };

  // 校验年龄或日期范围（支持单位：年、月、天）
  const handleValidDateOrAgeRange = (startValue: string, endValue: string) => {
    if (!startValue && !endValue) {
      return '请输入内容'; // 如果开始值和结束值都为空
    }

    // 校验是否为有效的数字
    const isValidNumber = (value: string) => {
      const numberValue = Number(value);
      return !isNaN(numberValue) && numberValue >= 0;
    };

    if (!isValidNumber(startValue) || !isValidNumber(endValue)) {
      return '输入值必须是有效的非负数字';
    }

    // 校验结束值不能小于开始值
    if (Number(endValue) < Number(startValue)) {
      return '结束值不能小于起始值';
    }

    // // 校验单位
    // const validUnits = ['1', '2', '3']; // '1'代表月，'2'代表岁，'3'代表天
    // if (!validUnits.includes(startUnit) || !validUnits.includes(endUnit)) {
    //   return '请选择有效的单位（年、月、天）';
    // }

    // // 根据单位优先级判断
    // const unitsPriority = {
    //   '1': 3, // 月是最大的单位
    //   '2': 2, // 岁是其次的单位
    //   '3': 1 // 天是最小的单位
    // };

    // const startUnitPriority = unitsPriority[startUnit];
    // const endUnitPriority = unitsPriority[endUnit];

    // // 如果开始单位的优先级高于结束单位的优先级，则返回错误
    // if (startUnitPriority > endUnitPriority) {
    //   return '起始单位大于结束单位，数值不合理';
    // }

    // // 校验日期范围，单位为月/岁/天
    // const startDate = new Date();
    // const endDate = new Date();

    // if (startUnit === '1') {
    //   // '1'代表月
    //   startDate.setMonth(startDate.getMonth() - Number(startValue));
    //   endDate.setMonth(endDate.getMonth() - Number(endValue));
    // } else if (startUnit === '2') {
    //   // '2'代表岁
    //   startDate.setFullYear(startDate.getFullYear() - Number(startValue));
    //   endDate.setFullYear(endDate.getFullYear() - Number(endValue));
    // } else if (startUnit === '3') {
    //   // '3'代表天
    //   startDate.setDate(startDate.getDate() - Number(startValue));
    //   endDate.setDate(endDate.getDate() - Number(endValue));
    // }

    // // 判断结束日期是否小于开始日期
    // if (endDate < startDate) {
    //   return '结束日期不能早于开始日期';
    // }

    return ''; // 校验通过，返回空字符串表示没有错误
  };

  return {
    validAge,
    validNumber,
    handleValidAge,
    handleValidDateOrAgeRange
  };
};
